<?php

namespace Liteerp\Patient\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Liteerp\Patient\Interfaces\ContactRepositoryInterface;

class ContactPublicController extends BaseController
{
    // use ContactWorkflow;

    /**
     * Constructor.
     *
     * @param type \Liteerp\Contact\Interfaces\ContactRepositoryInterface $contact
     *
     * @return type
     */
    public function __construct(ContactRepositoryInterface $contact)
    {
        $this->repository = $contact;
        parent::__construct();
    }

    /**
     * Show contact's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $contacts = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$patient::$contact.names'))
            ->view('$patient::public.contact.index')
            ->data(compact('$contacts'))
            ->output();
    }

    /**
     * Show contact's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $contacts = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$patient::$contact.names'))
            ->view('$patient::public.contact.index')
            ->data(compact('$contacts'))
            ->output();
    }

    /**
     * Show contact.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $contact = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$contact->name . trans('$patient::$contact.name'))
            ->view('$patient::public.contact.show')
            ->data(compact('$contact'))
            ->output();
    }

}
